# MCP Slack agent example

This example shows a "slack" Agent which has access to the 'slack' and 'filesystem' MCP servers.

You can use it to perform read/write actions on your Slack, as well as on your filesystem, including combination
actions such as writing slack messages to disk or reading files and sending them over slack.
